$set 15 #Common

$ #Yes
# Evet
$ #No
# Hayr

$ #DirectionTitle
# Yn
$ #DirectionHoriz
# Yatay
$ #DirectionVert
# Dikey

$ #AlwaysOnTop
# Her zaman stte

$ #PlacementTitle
# Yerleim
$ #PlacementTopLeft
# Sol st
$ #PlacementCenterLeft
# Sol orta 
$ #PlacementBottomLeft
# Sol alt
$ #PlacementTopCenter
# st orta
$ #PlacementBottomCenter
# Alt orta
$ #PlacementTopRight
# Sa st
$ #PlacementCenterRight
# Sa orta
$ #PlacementBottomRight
# Sa st
$ #PlacementLeftTop
# Sol st
$ #PlacementLeftCenter
# Sol orta
$ #PlacementLeftBottom
# Orta sol
$ #PlacementRightTop
# Sa st
$ #PlacementRightCenter
# Orta sa
$ #PlacementRightBottom
# Sa orta
$ #PlacementTopRelative
# st
$ #PlacementBottomRelative
# Orta
$ #PlacementLeftRelative
# Sol
$ #PlacementRightRelative
# Sa

$ #AutoHide
# Otomatik Gizle
